==> powerdevil_5.12.4.orig.tar.xz: powerdevil-5.12.4/daemon/powerdevil.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=preferences-system-power-management
X-KDE-DBus-ModuleName=powerdevil
Name=Power Management
Name[ar]=إدارة الطاقة
Name[bs]=Upravljanje napajanjem
Name[ca]=Gestió d'energia
Name[ca@valencia]=Gestió d'energia
Name[cs]=Správa napájení
Name[da]=Strømstyring
Name[de]=Energieverwaltung
Name[el]=Διαχείριση ενέργειας
Name[en_GB]=Power Management
Name[es]=Gestión de energía
Name[et]=Toitehaldus
Name[eu]=Energia-kudeaketa
Name[fi]=Virranhallinta
Name[fr]=Système de gestion de l'énergie
Name[gl]=Xestión da enerxía
Name[he]=ניהול חשמל
Name[hu]=Energiakezelés
Name[ia]=Gestion de energia
Name[id]=Pengelolaan Daya
Name[it]=Gestione energetica
Name[ja]=電源管理
Name[ko]=전원 관리
Name[lt]=Energijos valdymas
Name[nb]=Strømstyring
Name[nds]=Stroompleeg
Name[nl]=Energiebeheer
Name[nn]=Straumstyring
Name[pa]=ਪਾਵਰ ਪਰਬੰਧ
Name[pl]=Zarządzanie energią
Name[pt]=Gestão de Energia
Name[pt_BR]=Gerenciamento de energia
Name[ro]=Gestiunea alimentării
Name[ru]=Управление питанием
Name[sk]=Správa napájania
Name[sl]=Upravljanje z energijo
Name[sr]=Управљање напајањем
Name[sr@ijekavian]=Управљање напајањем
Name[sr@ijekavianlatin]=Upravljanje napajanjem
Name[sr@latin]=Upravljanje napajanjem
Name[sv]=Strömhantering
Name[tr]=Güç Yönetimi
Name[uk]=Керування живленням
Name[x-test]=xxPower Managementxx
Name[zh_CN]=电源管理
Name[zh_TW]=電源管理
Exec=@CMAKE_INSTALL_FULL_LIBEXECDIR@/org_kde_powerdevil
OnlyShowIn=KDE;

Comment=Battery, Display and CPU power management and notification
Comment[ar]=تنبيهات وإدارة طاقة المعالِج والعَرض والبطارية
Comment[bs]=Obavještavanje i upravljanje baterijom i napajanjem ekrana i procesora
Comment[ca]=Gestió d'energia i notificació de la bateria, pantalla i CPU
Comment[ca@valencia]=Gestió d'energia i notificació de la bateria, pantalla i CPU
Comment[cs]=Správa a oznamování baterie, zobrazení a výkonu CPU
Comment[da]=Bekendtgørelser om strømstyring for batteri, skærm og CPU
Comment[de]=Akku-, Anzeige- und Prozessorleistungsverwaltung und -benachrichtigung
Comment[el]=Μπαταρία, Εμφάνιση και διαχείριση ενέργειας και ειδοποιήσεων ΚΜΕ
Comment[en_GB]=Battery, Display and CPU power management and notification
Comment[es]=Gestión de energía y notificaciones de la batería, la pantalla y la CPU
Comment[et]=Aku, monitori ja protsessori toitehaldus ja märguanded
Comment[eu]=Bateriaren, bistaratzearen eta PUZaren energia kudeaketa eta jakinarazpenak
Comment[fi]=Akun, näytön ja suorittimen virranhallinta sekä ilmoitukset
Comment[fr]=Gestion et notifications de l'énergie pour les batteries, l'affichage et la consommation du processeur
Comment[gl]=Xestión e notificacións da xestión enerxética da batería, da pantalla e da CPU
Comment[hu]=Akkumulátor-, kijelző- és processzorkezelés és értesítés
Comment[ia]=Batteria, monstrator, gestion de energia de CPU e notification 
Comment[id]=Baterai, Penampil dan pengelolaan daya CPU dan pemberitahuan
Comment[it]=Gestione e notifica di batteria, schermo e consumo del processore
Comment[ja]=バッテリ、ディスプレイ、CPU の電源管理と通知
Comment[ko]=배터리, 디스플레이, CPU 전원 관리 및 알림
Comment[lt]=Baterijos, Monitoriaus ir CPU energijos valdymas ir pranešimai
Comment[nb]=Håndtering og varsling for strømstyring av batteri, skjerm og prosessor
Comment[nds]=Batterie-, Schirm- un Perzesser-Stroomkuntrull un -Bescheden
Comment[nl]=Energiebeheer voor accu, scherm en CPU en meldingen
Comment[nn]=Handtering og varsling for straumstyring av batteri, skjerm og prosessor
Comment[pa]=ਬੈਟਰੀ, ਡਿਸਪਲੇਅ ਤੇ CPU ਪਾਵਰ ਪਰਬੰਧ ਤੇ ਨੋਟੀਫਿਕੇਸ਼ਨ
Comment[pl]=Zarządzanie i powiadomienia o stanie baterii, wyświetlacza i zasilania procesora
Comment[pt]=Gestão de energia e notificações da bateria, ecrã e CPU
Comment[pt_BR]=Gerenciamento e notificação de energia, da tela e do CPU
Comment[ro]=Gestiune și notificări pentru acumulator, afișaj și putere procesor
Comment[ru]=Настройка яркости экрана, режима ожидания и питания
Comment[sk]=Správa napájania a upozornenia batérie, obrazovky a CPU
Comment[sl]=Upravljanje in obveščanje o porabi energije baterije, zaslona in procesorja
Comment[sr]=Обавештавање и управљање батеријом и напајањем екрана и процесора
Comment[sr@ijekavian]=Обавјештавање и управљање батеријом и напајањем екрана и процесора
Comment[sr@ijekavianlatin]=Obavještavanje i upravljanje baterijom i napajanjem ekrana i procesora
Comment[sr@latin]=Obaveštavanje i upravljanje baterijom i napajanjem ekrana i procesora
Comment[sv]=Hantering och underrättelser om batteri, skärm och processorkraft
Comment[tr]=Pil, Görüntü ve İşlemci güç yönetimi ve bildirimleri
Comment[uk]=Керування та сповіщення про стан акумуляторів та живлення дисплея і процесора
Comment[x-test]=xxBattery, Display and CPU power management and notificationxx
Comment[zh_CN]=电池、显示器和 CPU 电源管理及通知
Comment[zh_TW]=電池、顯示與 CPU 電力管理與通知

==> powerdevil-5.12.7.tar.xz: powerdevil-5.12.7/daemon/powerdevil.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=preferences-system-power-management
X-KDE-DBus-ModuleName=powerdevil
Name=Power Management
Name[ar]=إدارة الطاقة
Name[bs]=Upravljanje napajanjem
Name[ca]=Gestió d'energia
Name[ca@valencia]=Gestió d'energia
Name[cs]=Správa napájení
Name[da]=Strømstyring
Name[de]=Energieverwaltung
Name[el]=Διαχείριση ενέργειας
Name[en_GB]=Power Management
Name[es]=Gestión de energía
Name[et]=Toitehaldus
Name[eu]=Energia-kudeaketa
Name[fi]=Virranhallinta
Name[fr]=Système de gestion de l'énergie
Name[gl]=Xestión da enerxía
Name[he]=ניהול חשמל
Name[hu]=Energiakezelés
Name[ia]=Gestion de energia
Name[id]=Power Management
Name[it]=Gestione energetica
Name[ja]=電源管理
Name[ko]=전원 관리
Name[lt]=Energijos valdymas
Name[nb]=Strømstyring
Name[nds]=Stroompleeg
Name[nl]=Energiebeheer
Name[nn]=Straumstyring
Name[pa]=ਪਾਵਰ ਪਰਬੰਧ
Name[pl]=Zarządzanie energią
Name[pt]=Gestão de Energia
Name[pt_BR]=Gerenciamento de energia
Name[ro]=Gestiunea alimentării
Name[ru]=Управление питанием
Name[sk]=Správa napájania
Name[sl]=Upravljanje z energijo
Name[sr]=Управљање напајањем
Name[sr@ijekavian]=Управљање напајањем
Name[sr@ijekavianlatin]=Upravljanje napajanjem
Name[sr@latin]=Upravljanje napajanjem
Name[sv]=Strömhantering
Name[tr]=Güç Yönetimi
Name[uk]=Керування живленням
Name[x-test]=xxPower Managementxx
Name[zh_CN]=电源管理
Name[zh_TW]=電源管理
Exec=@CMAKE_INSTALL_FULL_LIBEXECDIR@/org_kde_powerdevil
OnlyShowIn=KDE;

Comment=Battery, Display and CPU power management and notification
Comment[ar]=تنبيهات وإدارة طاقة المعالِج والعَرض والبطارية
Comment[bs]=Obavještavanje i upravljanje baterijom i napajanjem ekrana i procesora
Comment[ca]=Gestió d'energia i notificació de la bateria, pantalla i CPU
Comment[ca@valencia]=Gestió d'energia i notificació de la bateria, pantalla i CPU
Comment[cs]=Správa a oznamování baterie, zobrazení a výkonu CPU
Comment[da]=Bekendtgørelser om strømstyring for batteri, skærm og CPU
Comment[de]=Akku-, Anzeige- und Prozessorleistungsverwaltung und -benachrichtigung
Comment[el]=Μπαταρία, Εμφάνιση και διαχείριση ενέργειας και ειδοποιήσεων ΚΜΕ
Comment[en_GB]=Battery, Display and CPU power management and notification
Comment[es]=Gestión de energía y notificaciones de la batería, la pantalla y la CPU
Comment[et]=Aku, monitori ja protsessori toitehaldus ja märguanded
Comment[eu]=Bateriaren, bistaratzearen eta PUZaren energia kudeaketa eta jakinarazpenak
Comment[fi]=Akun, näytön ja suorittimen virranhallinta sekä ilmoitukset
Comment[fr]=Gestion et notifications de l'énergie pour les batteries, l'affichage et la consommation du processeur
Comment[gl]=Xestión e notificacións da xestión enerxética da batería, da pantalla e da CPU
Comment[hu]=Akkumulátor-, kijelző- és processzorkezelés és értesítés
Comment[ia]=Batteria, monstrator, gestion de energia de CPU e notification 
Comment[id]=Baterai, Penampil dan pengelolaan daya CPU dan notifikasi
Comment[it]=Gestione e notifica di batteria, schermo e consumo del processore
Comment[ja]=バッテリ、ディスプレイ、CPU の電源管理と通知
Comment[ko]=배터리, 디스플레이, CPU 전원 관리 및 알림
Comment[lt]=Baterijos, Monitoriaus ir CPU energijos valdymas ir pranešimai
Comment[nb]=Håndtering og varsling for strømstyring av batteri, skjerm og prosessor
Comment[nds]=Batterie-, Schirm- un Perzesser-Stroomkuntrull un -Bescheden
Comment[nl]=Energiebeheer voor accu, scherm en CPU en meldingen
Comment[nn]=Handtering og varsling for straumstyring av batteri, skjerm og prosessor
Comment[pa]=ਬੈਟਰੀ, ਡਿਸਪਲੇਅ ਤੇ CPU ਪਾਵਰ ਪਰਬੰਧ ਤੇ ਨੋਟੀਫਿਕੇਸ਼ਨ
Comment[pl]=Zarządzanie i powiadomienia o stanie baterii, wyświetlacza i zasilania procesora
Comment[pt]=Gestão de energia e notificações da bateria, ecrã e CPU
Comment[pt_BR]=Gerenciamento e notificação de energia, da tela e do CPU
Comment[ro]=Gestiune și notificări pentru acumulator, afișaj și putere procesor
Comment[ru]=Настройка яркости экрана, режима ожидания и питания
Comment[sk]=Správa napájania a upozornenia batérie, obrazovky a CPU
Comment[sl]=Upravljanje in obveščanje o porabi energije baterije, zaslona in procesorja
Comment[sr]=Обавештавање и управљање батеријом и напајањем екрана и процесора
Comment[sr@ijekavian]=Обавјештавање и управљање батеријом и напајањем екрана и процесора
Comment[sr@ijekavianlatin]=Obavještavanje i upravljanje baterijom i napajanjem ekrana i procesora
Comment[sr@latin]=Obaveštavanje i upravljanje baterijom i napajanjem ekrana i procesora
Comment[sv]=Hantering och underrättelser om batteri, skärm och processorkraft
Comment[tr]=Pil, Görüntü ve İşlemci güç yönetimi ve bildirimleri
Comment[uk]=Керування та сповіщення про стан акумуляторів та живлення дисплея і процесора
Comment[x-test]=xxBattery, Display and CPU power management and notificationxx
Comment[zh_CN]=电池、显示器和 CPU 电源管理及通知
Comment[zh_TW]=電池、顯示與 CPU 電力管理與通知
